Macro origin_studio::writeln
source · macro_rules! writeln { ($dst:expr $(,)?) => { ... }; ($dst:expr, $($arg:tt)*) => { ... }; }
Writes formatted data into a buffer, with a newline appended.
macro_rules! writeln { ($dst:expr $(,)?) => { ... }; ($dst:expr, $($arg:tt)*) => { ... }; }
Writes formatted data into a buffer, with a newline appended.