Trait origin_studio::ops::Sub

1.0.0 · source ·
pub trait Sub<Rhs = Self> {
    type Output;

    // Required method
    fn sub(self, rhs: Rhs) -> Self::Output;
}
The subtraction operator -.

Note that Rhs is Self by default, but this is not mandatory. For example, std::time::SystemTime implements Sub<Duration>, which permits operations of the form SystemTime = SystemTime - Duration.

Examples

Subtractable points

use std::ops::Sub;

#[derive(Debug, Copy, Clone, PartialEq)]
struct Point {
    x: i32,
    y: i32,
}

impl Sub for Point {
    type Output = Self;

    fn sub(self, other: Self) -> Self::Output {
        Self {
            x: self.x - other.x,
            y: self.y - other.y,
        }
    }
}

assert_eq!(Point { x: 3, y: 3 } - Point { x: 2, y: 3 },
           Point { x: 1, y: 0 });

Implementing Sub with generics

Here is an example of the same Point struct implementing the Sub trait using generics.

use std::ops::Sub;

#[derive(Debug, PartialEq)]
struct Point<T> {
    x: T,
    y: T,
}

// Notice that the implementation uses the associated type `Output`.
impl<T: Sub<Output = T>> Sub for Point<T> {
    type Output = Self;

    fn sub(self, other: Self) -> Self::Output {
        Point {
            x: self.x - other.x,
            y: self.y - other.y,
        }
    }
}

assert_eq!(Point { x: 2, y: 3 } - Point { x: 1, y: 0 },
           Point { x: 1, y: 3 });

Required Associated Types

source

type Output

The resulting type after applying the - operator.

Required Methods

source

fn sub(self, rhs: Rhs) -> Self::Output

Performs the - operation.

Example
assert_eq!(12 - 1, 11);

Implementors

source

impl Sub for f32



type Output = f32

source

impl Sub for f64



type Output = f64

source

impl Sub for i8



type Output = i8

source

impl Sub for i16



type Output = i16

source

impl Sub for i32



type Output = i32

source

impl Sub for i64



type Output = i64

source

impl Sub for i128



type Output = i128

source

impl Sub for isize

source

impl Sub for u8



type Output = u8

source

impl Sub for u16



type Output = u16

source

impl Sub for u32



type Output = u32

source

impl Sub for u64



type Output = u64

source

impl Sub for u128



type Output = u128

source

impl Sub for usize

source

impl Sub for Assume

1.74.0 · source

impl Sub for Saturating<i8>

1.74.0 · source

impl Sub for Saturating<i16>

1.74.0 · source

impl Sub for Saturating<i32>

1.74.0 · source

impl Sub for Saturating<i64>

1.74.0 · source

impl Sub for Saturating<i128>

1.74.0 · source

impl Sub for Saturating<isize>

1.74.0 · source

impl Sub for Saturating<u8>

1.74.0 · source

impl Sub for Saturating<u16>

1.74.0 · source

impl Sub for Saturating<u32>

1.74.0 · source

impl Sub for Saturating<u64>

1.74.0 · source

impl Sub for Saturating<u128>

1.74.0 · source

impl Sub for Saturating<usize>

source

impl Sub for Wrapping<i8>

source

impl Sub for Wrapping<i16>

source

impl Sub for Wrapping<i32>

source

impl Sub for Wrapping<i64>

source

impl Sub for Wrapping<i128>

source

impl Sub for Wrapping<isize>

source

impl Sub for Wrapping<u8>

source

impl Sub for Wrapping<u16>

source

impl Sub for Wrapping<u32>

source

impl Sub for Wrapping<u64>

source

impl Sub for Wrapping<u128>

source

impl Sub for Wrapping<usize>

1.3.0 · source

impl Sub for Duration

source

impl Sub for CreateFlags

source

impl Sub for WatchFlags

source

impl Sub for Access

source

impl Sub for AtFlags

source

impl Sub for FallocateFlags

source

impl Sub for MemfdFlags

source

impl Sub for Mode



type Output = Mode

source

impl Sub for OFlags

source

impl Sub for RenameFlags

source

impl Sub for ResolveFlags

source

impl Sub for SealFlags

source

impl Sub for StatVfsMountFlags

source

impl Sub for StatxFlags

source

impl Sub for DupFlags

source

impl Sub for FdFlags

source

impl Sub for ReadWriteFlags

source

impl Sub for MapFlags

source

impl Sub for MlockAllFlags

source

impl Sub for MlockFlags

source

impl Sub for MprotectFlags

source

impl Sub for MremapFlags

source

impl Sub for MsyncFlags

source

impl Sub for ProtFlags

source

impl Sub for UserfaultfdFlags

source

impl Sub for MountFlags

source

impl Sub for MountPropagationFlags

source

impl Sub for UnmountFlags

source

impl Sub for FutexFlags

source

impl Sub for TimerfdFlags

source

impl Sub for TimerfdTimerFlags

source

impl Sub for XattrFlags

source

impl Sub for MembarrierQuery

source

impl Sub for PidfdFlags

source

impl Sub for PidfdGetfdFlags

source

impl Sub for FloatingPointEmulationControl

source

impl Sub for FloatingPointExceptionMode

source

impl Sub for SpeculationFeatureControl

source

impl Sub for SpeculationFeatureState

source

impl Sub for UnalignedAccessControl

source

impl Sub for WaitOptions

source

impl Sub for WaitidOptions

source

impl Sub for CapabilityFlags

source

impl Sub for CapabilitiesSecureBits

source

impl Sub for TaggedAddressMode

source

impl Sub for ThreadNameSpaceType

source

impl Sub for UnshareFlags

source

impl Sub<&f32> for &f32



type Output = <f32 as Sub>::Output

source

impl Sub<&f32> for f32



type Output = <f32 as Sub>::Output

source

impl Sub<&f64> for &f64



type Output = <f64 as Sub>::Output

source

impl Sub<&f64> for f64



type Output = <f64 as Sub>::Output

source

impl Sub<&i8> for &i8



type Output = <i8 as Sub>::Output

source

impl Sub<&i8> for i8



type Output = <i8 as Sub>::Output

source

impl Sub<&i16> for &i16



type Output = <i16 as Sub>::Output

source

impl Sub<&i16> for i16



type Output = <i16 as Sub>::Output

source

impl Sub<&i32> for &i32



type Output = <i32 as Sub>::Output

source

impl Sub<&i32> for i32



type Output = <i32 as Sub>::Output

source

impl Sub<&i64> for &i64



type Output = <i64 as Sub>::Output

source

impl Sub<&i64> for i64



type Output = <i64 as Sub>::Output

source

impl Sub<&i128> for &i128



type Output = <i128 as Sub>::Output

source

impl Sub<&i128> for i128



type Output = <i128 as Sub>::Output

source

impl Sub<&isize> for &isize



type Output = <isize as Sub>::Output

source

impl Sub<&isize> for isize



type Output = <isize as Sub>::Output

source

impl Sub<&u8> for &u8



type Output = <u8 as Sub>::Output

source

impl Sub<&u8> for u8



type Output = <u8 as Sub>::Output

source

impl Sub<&u16> for &u16



type Output = <u16 as Sub>::Output

source

impl Sub<&u16> for u16



type Output = <u16 as Sub>::Output

source

impl Sub<&u32> for &u32



type Output = <u32 as Sub>::Output

source

impl Sub<&u32> for u32



type Output = <u32 as Sub>::Output

source

impl Sub<&u64> for &u64



type Output = <u64 as Sub>::Output

source

impl Sub<&u64> for u64



type Output = <u64 as Sub>::Output

source

impl Sub<&u128> for &u128



type Output = <u128 as Sub>::Output

source

impl Sub<&u128> for u128



type Output = <u128 as Sub>::Output

source

impl Sub<&usize> for &usize



type Output = <usize as Sub>::Output

source

impl Sub<&usize> for usize



type Output = <usize as Sub>::Output

1.74.0 · source

impl Sub<&Saturating<i8>> for &Saturating<i8>

1.74.0 · source

impl Sub<&Saturating<i8>> for Saturating<i8>

1.74.0 · source

impl Sub<&Saturating<i16>> for &Saturating<i16>

1.74.0 · source

impl Sub<&Saturating<i16>> for Saturating<i16>

1.74.0 · source

impl Sub<&Saturating<i32>> for &Saturating<i32>

1.74.0 · source

impl Sub<&Saturating<i32>> for Saturating<i32>

1.74.0 · source

impl Sub<&Saturating<i64>> for &Saturating<i64>

1.74.0 · source

impl Sub<&Saturating<i64>> for Saturating<i64>

1.74.0 · source

impl Sub<&Saturating<i128>> for &Saturating<i128>

1.74.0 · source

impl Sub<&Saturating<i128>> for Saturating<i128>

1.74.0 · source

impl Sub<&Saturating<isize>> for &Saturating<isize>

1.74.0 · source

impl Sub<&Saturating<isize>> for Saturating<isize>

1.74.0 · source

impl Sub<&Saturating<u8>> for &Saturating<u8>

1.74.0 · source

impl Sub<&Saturating<u8>> for Saturating<u8>

1.74.0 · source

impl Sub<&Saturating<u16>> for &Saturating<u16>

1.74.0 · source

impl Sub<&Saturating<u16>> for Saturating<u16>

1.74.0 · source

impl Sub<&Saturating<u32>> for &Saturating<u32>

1.74.0 · source

impl Sub<&Saturating<u32>> for Saturating<u32>

1.74.0 · source

impl Sub<&Saturating<u64>> for &Saturating<u64>

1.74.0 · source

impl Sub<&Saturating<u64>> for Saturating<u64>

1.74.0 · source

impl Sub<&Saturating<u128>> for &Saturating<u128>

1.74.0 · source

impl Sub<&Saturating<u128>> for Saturating<u128>

1.74.0 · source

impl Sub<&Saturating<usize>> for &Saturating<usize>

1.74.0 · source

impl Sub<&Saturating<usize>> for Saturating<usize>

1.14.0 · source

impl Sub<&Wrapping<i8>> for &Wrapping<i8>



type Output = <Wrapping<i8> as Sub>::Output

1.14.0 · source

impl Sub<&Wrapping<i8>> for Wrapping<i8>



type Output = <Wrapping<i8> as Sub>::Output

1.14.0 · source

impl Sub<&Wrapping<i16>> for &Wrapping<i16>

1.14.0 · source

impl Sub<&Wrapping<i16>> for Wrapping<i16>

1.14.0 · source

impl Sub<&Wrapping<i32>> for &Wrapping<i32>

1.14.0 · source

impl Sub<&Wrapping<i32>> for Wrapping<i32>

1.14.0 · source

impl Sub<&Wrapping<i64>> for &Wrapping<i64>

1.14.0 · source

impl Sub<&Wrapping<i64>> for Wrapping<i64>

1.14.0 · source

impl Sub<&Wrapping<i128>> for &Wrapping<i128>

1.14.0 · source

impl Sub<&Wrapping<i128>> for Wrapping<i128>

1.14.0 · source

impl Sub<&Wrapping<isize>> for &Wrapping<isize>

1.14.0 · source

impl Sub<&Wrapping<isize>> for Wrapping<isize>

1.14.0 · source

impl Sub<&Wrapping<u8>> for &Wrapping<u8>



type Output = <Wrapping<u8> as Sub>::Output

1.14.0 · source

impl Sub<&Wrapping<u8>> for Wrapping<u8>



type Output = <Wrapping<u8> as Sub>::Output

1.14.0 · source

impl Sub<&Wrapping<u16>> for &Wrapping<u16>

1.14.0 · source

impl Sub<&Wrapping<u16>> for Wrapping<u16>

1.14.0 · source

impl Sub<&Wrapping<u32>> for &Wrapping<u32>

1.14.0 · source

impl Sub<&Wrapping<u32>> for Wrapping<u32>

1.14.0 · source

impl Sub<&Wrapping<u64>> for &Wrapping<u64>

1.14.0 · source

impl Sub<&Wrapping<u64>> for Wrapping<u64>

1.14.0 · source

impl Sub<&Wrapping<u128>> for &Wrapping<u128>

1.14.0 · source

impl Sub<&Wrapping<u128>> for Wrapping<u128>

1.14.0 · source

impl Sub<&Wrapping<usize>> for &Wrapping<usize>

1.14.0 · source

impl Sub<&Wrapping<usize>> for Wrapping<usize>

source

impl<'a> Sub<f32> for &'a f32



type Output = <f32 as Sub>::Output

source

impl<'a> Sub<f64> for &'a f64



type Output = <f64 as Sub>::Output

source

impl<'a> Sub<i8> for &'a i8



type Output = <i8 as Sub>::Output

source

impl<'a> Sub<i16> for &'a i16



type Output = <i16 as Sub>::Output

source

impl<'a> Sub<i32> for &'a i32



type Output = <i32 as Sub>::Output

source

impl<'a> Sub<i64> for &'a i64



type Output = <i64 as Sub>::Output

source

impl<'a> Sub<i128> for &'a i128



type Output = <i128 as Sub>::Output

source

impl<'a> Sub<isize> for &'a isize



type Output = <isize as Sub>::Output

source

impl<'a> Sub<u8> for &'a u8



type Output = <u8 as Sub>::Output

source

impl<'a> Sub<u16> for &'a u16



type Output = <u16 as Sub>::Output

source

impl<'a> Sub<u32> for &'a u32



type Output = <u32 as Sub>::Output

source

impl<'a> Sub<u64> for &'a u64



type Output = <u64 as Sub>::Output

source

impl<'a> Sub<u128> for &'a u128



type Output = <u128 as Sub>::Output

source

impl<'a> Sub<usize> for &'a usize



type Output = <usize as Sub>::Output

1.74.0 · source

impl<'a> Sub<Saturating<i8>> for &'a Saturating<i8>

1.74.0 · source

impl<'a> Sub<Saturating<i16>> for &'a Saturating<i16>

1.74.0 · source

impl<'a> Sub<Saturating<i32>> for &'a Saturating<i32>

1.74.0 · source

impl<'a> Sub<Saturating<i64>> for &'a Saturating<i64>

1.74.0 · source

impl<'a> Sub<Saturating<i128>> for &'a Saturating<i128>

1.74.0 · source

impl<'a> Sub<Saturating<isize>> for &'a Saturating<isize>

1.74.0 · source

impl<'a> Sub<Saturating<u8>> for &'a Saturating<u8>

1.74.0 · source

impl<'a> Sub<Saturating<u16>> for &'a Saturating<u16>

1.74.0 · source

impl<'a> Sub<Saturating<u32>> for &'a Saturating<u32>

1.74.0 · source

impl<'a> Sub<Saturating<u64>> for &'a Saturating<u64>

1.74.0 · source

impl<'a> Sub<Saturating<u128>> for &'a Saturating<u128>

1.74.0 · source

impl<'a> Sub<Saturating<usize>> for &'a Saturating<usize>

1.14.0 · source

impl<'a> Sub<Wrapping<i8>> for &'a Wrapping<i8>



type Output = <Wrapping<i8> as Sub>::Output

1.14.0 · source

impl<'a> Sub<Wrapping<i16>> for &'a Wrapping<i16>

1.14.0 · source

impl<'a> Sub<Wrapping<i32>> for &'a Wrapping<i32>

1.14.0 · source

impl<'a> Sub<Wrapping<i64>> for &'a Wrapping<i64>

1.14.0 · source

impl<'a> Sub<Wrapping<i128>> for &'a Wrapping<i128>

1.14.0 · source

impl<'a> Sub<Wrapping<isize>> for &'a Wrapping<isize>

1.14.0 · source

impl<'a> Sub<Wrapping<u8>> for &'a Wrapping<u8>



type Output = <Wrapping<u8> as Sub>::Output

1.14.0 · source

impl<'a> Sub<Wrapping<u16>> for &'a Wrapping<u16>

1.14.0 · source

impl<'a> Sub<Wrapping<u32>> for &'a Wrapping<u32>

1.14.0 · source

impl<'a> Sub<Wrapping<u64>> for &'a Wrapping<u64>

1.14.0 · source

impl<'a> Sub<Wrapping<u128>> for &'a Wrapping<u128>

1.14.0 · source

impl<'a> Sub<Wrapping<usize>> for &'a Wrapping<usize>

source

impl<'lhs, 'rhs, T, const LANES: usize> Sub<&'rhs Simd<T, LANES>> for &'lhs Simd<T, LANES>where T: SimdElement, Simd<T, LANES>: Sub<Output = Simd<T, LANES>>, LaneCount<LANES>: SupportedLaneCount,



type Output = Simd<T, LANES>

source

impl<T, A> Sub<&BTreeSet<T, A>> for &BTreeSet<T, A>where T: Ord + Clone, A: Allocator + Clone,



type Output = BTreeSet<T, A>

source

impl<T, const LANES: usize> Sub<&Simd<T, LANES>> for Simd<T, LANES>where T: SimdElement, Simd<T, LANES>: Sub<Output = Simd<T, LANES>>, LaneCount<LANES>: SupportedLaneCount,



type Output = Simd<T, LANES>

source

impl<T, const LANES: usize> Sub<Simd<T, LANES>> for &Simd<T, LANES>where T: SimdElement, Simd<T, LANES>: Sub<Output = Simd<T, LANES>>, LaneCount<LANES>: SupportedLaneCount,



type Output = Simd<T, LANES>

source

impl<const N: usize> Sub for Simd<f32, N>where f32: SimdElement, LaneCount<N>: SupportedLaneCount,



type Output = Simd<f32, N>

source

impl<const N: usize> Sub for Simd<f64, N>where f64: SimdElement, LaneCount<N>: SupportedLaneCount,



type Output = Simd<f64, N>

source

impl<const N: usize> Sub for Simd<i8, N>where i8: SimdElement, LaneCount<N>: SupportedLaneCount,



type Output = Simd<i8, N>

source

impl<const N: usize> Sub for Simd<i16, N>where i16: SimdElement, LaneCount<N>: SupportedLaneCount,



type Output = Simd<i16, N>

source

impl<const N: usize> Sub for Simd<i32, N>where i32: SimdElement, LaneCount<N>: SupportedLaneCount,



type Output = Simd<i32, N>

source

impl<const N: usize> Sub for Simd<i64, N>where i64: SimdElement, LaneCount<N>: SupportedLaneCount,



type Output = Simd<i64, N>

source

impl<const N: usize> Sub for Simd<isize, N>where isize: SimdElement, LaneCount<N>: SupportedLaneCount,



type Output = Simd<isize, N>

source

impl<const N: usize> Sub for Simd<u8, N>where u8: SimdElement, LaneCount<N>: SupportedLaneCount,



type Output = Simd<u8, N>

source

impl<const N: usize> Sub for Simd<u16, N>where u16: SimdElement, LaneCount<N>: SupportedLaneCount,



type Output = Simd<u16, N>

source

impl<const N: usize> Sub for Simd<u32, N>where u32: SimdElement, LaneCount<N>: SupportedLaneCount,



type Output = Simd<u32, N>

source

impl<const N: usize> Sub for Simd<u64, N>where u64: SimdElement, LaneCount<N>: SupportedLaneCount,



type Output = Simd<u64, N>

source

impl<const N: usize> Sub for Simd<usize, N>where usize: SimdElement, LaneCount<N>: SupportedLaneCount,



type Output = Simd<usize, N>